@@ -18,10 +18,11 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
 	testclaim "github.com/openshift/hive/pkg/test/clusterclaim"
 	testcd "github.com/openshift/hive/pkg/test/clusterdeployment"
+	testcp "github.com/openshift/hive/pkg/test/clusterpool"
 	testgeneric "github.com/openshift/hive/pkg/test/generic"
 )
 
@@ -31,6 +32,7 @@ const (
 	clusterName          = "test-cluster"
 	kubeconfigSecretName = "kubeconfig-secret"
 	passwordSecretName   = "password-secret"
+	testLeasePoolName    = "test-cluster-pool"
 )
 
 func init() {
@@ -57,9 +59,33 @@ func TestReconcileClusterClaim(t *testing.T) {
 	hivev1.AddToScheme(scheme)
 	rbacv1.AddToScheme(scheme)
 
+	poolBuilder := testcp.FullBuilder(claimNamespace, testLeasePoolName, scheme).
+		GenericOptions(
+			testgeneric.WithFinalizer(finalizer),
+		).
+		Options(
+			testcp.ForAWS("secret", "us-east-1"),
+			testcp.WithBaseDomain("test-domain"),
+			testcp.WithImageSet("test-imageset"),
+		)
 	claimBuilder := testclaim.FullBuilder(claimNamespace, claimName, scheme).Options(
 		testclaim.WithSubjects(subjects),
 	)
+	initializedClaimBuilder := testclaim.FullBuilder(claimNamespace, claimName, scheme).Options(
+		testclaim.WithSubjects(subjects),
+		testclaim.WithCondition(hivev1.ClusterClaimCondition{
+			Status: corev1.ConditionUnknown,
+			Type:   hivev1.ClusterClaimPendingCondition,
+		}),
+		testclaim.WithCondition(hivev1.ClusterClaimCondition{
+			Status: corev1.ConditionUnknown,
+			Type:   hivev1.ClusterClaimClusterDeletedCondition,
+		}),
+		testclaim.WithCondition(hivev1.ClusterClaimCondition{
+			Status: corev1.ConditionUnknown,
+			Type:   hivev1.ClusterRunningCondition,
+		}),
+	)
 	cdBuilder := testcd.FullBuilder(clusterName, clusterName, scheme).Options(
 		func(cd *hivev1.ClusterDeployment) {
 			cd.Spec.ClusterMetadata = &hivev1.ClusterMetadata{
@@ -85,8 +111,29 @@ func TestReconcileClusterClaim(t *testing.T) {
 		expectedRequeueAfter                   *time.Duration
 	}{
 		{
-			name:  "new assignment",
+			name:  "initialize conditions",
 			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			cd: cdBuilder.Build(
+				testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool")),
+			expectNoFinalizer: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:   hivev1.ClusterClaimPendingCondition,
+					Status: corev1.ConditionUnknown,
+				},
+				{
+					Type:   hivev1.ClusterClaimClusterDeletedCondition,
+					Status: corev1.ConditionUnknown,
+				},
+				{
+					Type:   hivev1.ClusterRunningCondition,
+					Status: corev1.ConditionUnknown,
+				},
+			},
+		},
+		{
+			name:  "new assignment",
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool"),
 				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
@@ -113,7 +160,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "existing assignment",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
 				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
@@ -140,7 +187,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:               "assignment conflict",
-			claim:              claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim:              initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd:                 cdBuilder.Build(testcd.WithClusterPoolReference(claimNamespace, "test-pool", "other-claim")),
 			expectNoAssignment: true,
 			expectedConditions: []hivev1.ClusterClaimCondition{{
@@ -152,7 +199,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "deleted cluster",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			expectedConditions: []hivev1.ClusterClaimCondition{{
 				Type:    hivev1.ClusterClaimClusterDeletedCondition,
 				Status:  corev1.ConditionTrue,
@@ -163,7 +210,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "new assignment clears pending condition",
-			claim: claimBuilder.Build(
+			claim: initializedClaimBuilder.Build(
 				testclaim.WithCluster(clusterName),
 				testclaim.WithCondition(
 					hivev1.ClusterClaimCondition{
@@ -198,7 +245,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with no assignment",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(),
@@ -208,7 +255,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with unclaimed assignment",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(testclaim.WithCluster(clusterName)),
@@ -222,7 +269,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with claimed assignment",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(testclaim.WithCluster(clusterName)),
@@ -237,7 +284,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with missing clusterdeployment",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(testclaim.WithCluster(clusterName)),
@@ -246,7 +293,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with deleted clusterdeployment",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(testclaim.WithCluster(clusterName)),
@@ -261,7 +308,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "deleted claim with clusterdeployment assigned to other claim",
-			claim: claimBuilder.GenericOptions(
+			claim: initializedClaimBuilder.GenericOptions(
 				testgeneric.WithFinalizer(finalizer),
 				testgeneric.Deleted(),
 			).Build(testclaim.WithCluster(clusterName)),
@@ -270,7 +317,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "no RBAC when no subjects",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName), testclaim.WithSubjects(nil)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName), testclaim.WithSubjects(nil)),
 			cd: cdBuilder.Build(testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool"),
 				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
 					Type:   hivev1.ClusterHibernatingCondition,
@@ -295,7 +342,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "update existing role",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool"),
 				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
@@ -329,7 +376,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "update existing rolebinding",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool"),
 				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
@@ -364,7 +411,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "new assignment bring cluster out of hibernation",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithUnclaimedClusterPoolReference(claimNamespace, "test-pool"),
 				testcd.WithPowerState(hivev1.HibernatingClusterPowerState),
@@ -393,7 +440,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name:  "existing assignment does not change power state",
-			claim: claimBuilder.Build(testclaim.WithCluster(clusterName)),
+			claim: initializedClaimBuilder.Build(testclaim.WithCluster(clusterName)),
 			cd: cdBuilder.Build(
 				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
 				testcd.WithPowerState(hivev1.HibernatingClusterPowerState),
@@ -422,7 +469,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 		},
 		{
 			name: "claim with elapsed lifetime is deleted",
-			claim: claimBuilder.Build(
+			claim: initializedClaimBuilder.Build(
 				testclaim.WithCluster(clusterName),
 				testclaim.WithLifetime(1*time.Hour),
 				testclaim.WithCondition(hivev1.ClusterClaimCondition{
@@ -454,9 +501,196 @@ func TestReconcileClusterClaim(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "claim with elapsed pool lifetime is deleted as set by pool default",
+			claim: initializedClaimBuilder.Build(
+				testclaim.WithPool(testLeasePoolName),
+				testclaim.WithCluster(clusterName),
+				testclaim.WithCondition(hivev1.ClusterClaimCondition{
+					Type:               hivev1.ClusterClaimPendingCondition,
+					Status:             corev1.ConditionFalse,
+					LastTransitionTime: metav1.NewTime(time.Now().Add(-1 * time.Hour)),
+				}),
+			),
+			cd: cdBuilder.Build(
+				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
+				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
+					Type:   hivev1.ClusterHibernatingCondition,
+					Status: corev1.ConditionTrue,
+				}),
+			),
+			existing: []runtime.Object{
+				poolBuilder.Build(testcp.WithDefaultClaimLifetime(1 * time.Hour)),
+			},
+			expectDeleted: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:    hivev1.ClusterClaimPendingCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "ClusterClaimed",
+					Message: "Cluster claimed",
+				},
+				{
+					Type:    hivev1.ClusterRunningCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "Resuming",
+					Message: "Waiting for cluster to be running",
+				},
+			},
+		},
+		{
+			name: "claim with elapsed pool lifetime is deleted as set by pool maximum",
+			claim: initializedClaimBuilder.Build(
+				testclaim.WithPool(testLeasePoolName),
+				testclaim.WithCluster(clusterName),
+				testclaim.WithCondition(hivev1.ClusterClaimCondition{
+					Type:               hivev1.ClusterClaimPendingCondition,
+					Status:             corev1.ConditionFalse,
+					LastTransitionTime: metav1.NewTime(time.Now().Add(-1 * time.Hour)),
+				}),
+			),
+			cd: cdBuilder.Build(
+				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
+				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
+					Type:   hivev1.ClusterHibernatingCondition,
+					Status: corev1.ConditionTrue,
+				}),
+			),
+			existing: []runtime.Object{
+				poolBuilder.Build(testcp.WithMaximumClaimLifetime(1 * time.Hour)),
+			},
+			expectDeleted: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:    hivev1.ClusterClaimPendingCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "ClusterClaimed",
+					Message: "Cluster claimed",
+				},
+				{
+					Type:    hivev1.ClusterRunningCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "Resuming",
+					Message: "Waiting for cluster to be running",
+				},
+			},
+		},
+		{
+			name: "claim with elapsed smaller lifetime is deleted, where pool maximum is smaller",
+			claim: initializedClaimBuilder.Build(
+				testclaim.WithPool(testLeasePoolName),
+				testclaim.WithCluster(clusterName),
+				testclaim.WithLifetime(2*time.Hour),
+				testclaim.WithCondition(hivev1.ClusterClaimCondition{
+					Type:               hivev1.ClusterClaimPendingCondition,
+					Status:             corev1.ConditionFalse,
+					LastTransitionTime: metav1.NewTime(time.Now().Add(-1 * time.Hour)),
+				}),
+			),
+			cd: cdBuilder.Build(
+				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
+				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
+					Type:   hivev1.ClusterHibernatingCondition,
+					Status: corev1.ConditionTrue,
+				}),
+			),
+			existing: []runtime.Object{
+				poolBuilder.Build(testcp.WithMaximumClaimLifetime(1 * time.Hour)),
+			},
+			expectDeleted: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:    hivev1.ClusterClaimPendingCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "ClusterClaimed",
+					Message: "Cluster claimed",
+				},
+				{
+					Type:    hivev1.ClusterRunningCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "Resuming",
+					Message: "Waiting for cluster to be running",
+				},
+			},
+		},
+		{
+			name: "claim with elapsed smaller lifetime is deleted, where pool maximum is smaller than default",
+			claim: initializedClaimBuilder.Build(
+				testclaim.WithPool(testLeasePoolName),
+				testclaim.WithCluster(clusterName),
+				testclaim.WithCondition(hivev1.ClusterClaimCondition{
+					Type:               hivev1.ClusterClaimPendingCondition,
+					Status:             corev1.ConditionFalse,
+					LastTransitionTime: metav1.NewTime(time.Now().Add(-1 * time.Hour)),
+				}),
+			),
+			cd: cdBuilder.Build(
+				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
+				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
+					Type:   hivev1.ClusterHibernatingCondition,
+					Status: corev1.ConditionTrue,
+				}),
+			),
+			existing: []runtime.Object{
+				poolBuilder.Build(testcp.WithDefaultClaimLifetime(2*time.Hour), testcp.WithMaximumClaimLifetime(1*time.Hour)),
+			},
+			expectDeleted: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:    hivev1.ClusterClaimPendingCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "ClusterClaimed",
+					Message: "Cluster claimed",
+				},
+				{
+					Type:    hivev1.ClusterRunningCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "Resuming",
+					Message: "Waiting for cluster to be running",
+				},
+			},
+		},
+		{
+			name: "claim with elapsed smaller lifetime is deleted, where claim is smaller",
+			claim: initializedClaimBuilder.Build(
+				testclaim.WithPool(testLeasePoolName),
+				testclaim.WithCluster(clusterName),
+				testclaim.WithLifetime(1*time.Hour),
+				testclaim.WithCondition(hivev1.ClusterClaimCondition{
+					Type:               hivev1.ClusterClaimPendingCondition,
+					Status:             corev1.ConditionFalse,
+					LastTransitionTime: metav1.NewTime(time.Now().Add(-1 * time.Hour)),
+				}),
+			),
+			cd: cdBuilder.Build(
+				testcd.WithClusterPoolReference(claimNamespace, "test-pool", claimName),
+				testcd.WithCondition(hivev1.ClusterDeploymentCondition{
+					Type:   hivev1.ClusterHibernatingCondition,
+					Status: corev1.ConditionTrue,
+				}),
+			),
+			existing: []runtime.Object{
+				poolBuilder.Build(testcp.WithMaximumClaimLifetime(2 * time.Hour)),
+			},
+			expectDeleted: true,
+			expectedConditions: []hivev1.ClusterClaimCondition{
+				{
+					Type:    hivev1.ClusterClaimPendingCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "ClusterClaimed",
+					Message: "Cluster claimed",
+				},
+				{
+					Type:    hivev1.ClusterRunningCondition,
+					Status:  corev1.ConditionFalse,
+					Reason:  "Resuming",
+					Message: "Waiting for cluster to be running",
+				},
+			},
+		},
 		{
 			name: "claim with non-elapsed lifetime is not deleted",
-			claim: claimBuilder.Build(
+			claim: initializedClaimBuilder.Build(
 				testclaim.WithCluster(clusterName),
 				testclaim.WithLifetime(3*time.Hour),
 				testclaim.WithCondition(hivev1.ClusterClaimCondition{
@@ -521,7 +755,7 @@ func TestReconcileClusterClaim(t *testing.T) {
 				},
 			}
 
-			result, err := rcp.Reconcile(reconcileRequest)
+			result, err := rcp.Reconcile(context.TODO(), reconcileRequest)
 			require.NoError(t, err, "unexpected error from Reconcile")
 
 			if test.expectedRequeueAfter == nil {
@@ -572,12 +806,18 @@ func TestReconcileClusterClaim(t *testing.T) {
 				assert.NotEmpty(t, claim.Spec.Namespace, "expected assignment set on claim")
 			}
 
-			for i := range claim.Status.Conditions {
-				cond := &claim.Status.Conditions[i]
-				cond.LastTransitionTime = metav1.Time{}
-				cond.LastProbeTime = metav1.Time{}
+			for _, expectedCond := range test.expectedConditions {
+				cond := controllerutils.FindClusterClaimCondition(claim.Status.Conditions, expectedCond.Type)
+				if assert.NotNilf(t, cond, "did not find expected condition type: %v", expectedCond.Type) {
+					assert.Equal(t, expectedCond.Status, cond.Status, "condition found with unexpected status")
+					if expectedCond.Reason != "" {
+						assert.Equal(t, expectedCond.Reason, cond.Reason, "condition found with unexpected reason")
+					}
+					if expectedCond.Message != "" {
+						assert.Equal(t, expectedCond.Message, cond.Message, "condition found with unexpected message")
+					}
+				}
 			}
-			assert.ElementsMatch(t, test.expectedConditions, claim.Status.Conditions, "unexpected conditions")
 
 			if test.expectNoFinalizer {
 				assert.NotContains(t, claim.Finalizers, finalizer, "expected no finalizer on claim")
@@ -621,6 +861,88 @@ func TestReconcileClusterClaim(t *testing.T) {
 	}
 }
 
+func Test_getClaimLifetime(t *testing.T) {
+	cases := []struct {
+		name string
+
+		defaultLifetime *metav1.Duration
+		maximumLifetime *metav1.Duration
+		claimLifetime   *metav1.Duration
+
+		expected *metav1.Duration
+	}{{
+		name: "no lifetime set",
+
+		expected: nil,
+	}, {
+		name:          "claim lifetime set",
+		claimLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "no claim lifetime set, but default for pool",
+		defaultLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "claim lifetime set, and default for pool",
+		defaultLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+		claimLifetime:   &metav1.Duration{Duration: 3 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 3 * time.Hour},
+	}, {
+		name:            "maximum pool lifetime set",
+		maximumLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "claim lifetime set, and maximum pool lifetime set to higher",
+		maximumLifetime: &metav1.Duration{Duration: 2 * time.Hour},
+		claimLifetime:   &metav1.Duration{Duration: 1 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "claim lifetime set, and maximum pool lifetime set to lower",
+		maximumLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+		claimLifetime:   &metav1.Duration{Duration: 2 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "default lifetime set, and maximum pool lifetime set to lower",
+		defaultLifetime: &metav1.Duration{Duration: 2 * time.Hour},
+		maximumLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}, {
+		name:            "default lifetime set, and maximum pool lifetime set to higher",
+		defaultLifetime: &metav1.Duration{Duration: 1 * time.Hour},
+		maximumLifetime: &metav1.Duration{Duration: 2 * time.Hour},
+
+		expected: &metav1.Duration{Duration: 1 * time.Hour},
+	}}
+
+	for _, test := range cases {
+		t.Run(test.name, func(t *testing.T) {
+			var poolLifetime *hivev1.ClusterPoolClaimLifetime
+			if test.defaultLifetime != nil {
+				if poolLifetime == nil {
+					poolLifetime = &hivev1.ClusterPoolClaimLifetime{}
+				}
+				poolLifetime.Default = test.defaultLifetime
+			}
+			if test.maximumLifetime != nil {
+				if poolLifetime == nil {
+					poolLifetime = &hivev1.ClusterPoolClaimLifetime{}
+				}
+				poolLifetime.Maximum = test.maximumLifetime
+			}
+
+			got := getClaimLifetime(poolLifetime, test.claimLifetime)
+			assert.Equal(t, test.expected, got, "expected the lifetimes to match")
+		})
+	}
+}
+
 func testRole() *rbacv1.Role {
 	return &rbacv1.Role{
 		ObjectMeta: metav1.ObjectMeta{
