@@ -36,8 +36,8 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/source"
 	"sigs.k8s.io/yaml"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
-	hiveintv1alpha1 "github.com/openshift/hive/pkg/apis/hiveinternal/v1alpha1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
+	hiveintv1alpha1 "github.com/openshift/hive/apis/hiveinternal/v1alpha1"
 	"github.com/openshift/hive/pkg/constants"
 	hivemetrics "github.com/openshift/hive/pkg/controller/metrics"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
@@ -199,28 +199,22 @@ func AddToManager(mgr manager.Manager, r *ReconcileClusterSync, concurrentReconc
 	// Watch for changes to SyncSets
 	if err := c.Watch(
 		&source.Kind{Type: &hivev1.SyncSet{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: handler.ToRequestsFunc(requestsForSyncSet),
-		},
-	); err != nil {
+		handler.EnqueueRequestsFromMapFunc(requestsForSyncSet)); err != nil {
 		return err
 	}
 
 	// Watch for changes to SelectorSyncSets
 	if err := c.Watch(
 		&source.Kind{Type: &hivev1.SelectorSyncSet{}},
-		&handler.EnqueueRequestsFromMapFunc{
-			ToRequests: requestsForSelectorSyncSet(r.Client, r.logger),
-		},
-	); err != nil {
+		handler.EnqueueRequestsFromMapFunc(requestsForSelectorSyncSet(r.Client, r.logger))); err != nil {
 		return err
 	}
 
 	return nil
 }
 
-func requestsForSyncSet(o handler.MapObject) []reconcile.Request {
-	ss, ok := o.Object.(*hivev1.SyncSet)
+func requestsForSyncSet(o client.Object) []reconcile.Request {
+	ss, ok := o.(*hivev1.SyncSet)
 	if !ok {
 		return nil
 	}
@@ -232,9 +226,9 @@ func requestsForSyncSet(o handler.MapObject) []reconcile.Request {
 	return requests
 }
 
-func requestsForSelectorSyncSet(c client.Client, logger log.FieldLogger) handler.ToRequestsFunc {
-	return func(o handler.MapObject) []reconcile.Request {
-		sss, ok := o.Object.(*hivev1.SelectorSyncSet)
+func requestsForSelectorSyncSet(c client.Client, logger log.FieldLogger) handler.MapFunc {
+	return func(o client.Object) []reconcile.Request {
+		sss, ok := o.(*hivev1.SelectorSyncSet)
 		if !ok {
 			return nil
 		}
@@ -335,7 +329,7 @@ func (r *ReconcileClusterSync) isSyncAssignedToMe(sts *appsv1.StatefulSet, cd *h
 
 // Reconcile reads the state of the ClusterDeployment and applies any SyncSets or SelectorSyncSets that need to be
 // applied or re-applied.
-func (r *ReconcileClusterSync) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+func (r *ReconcileClusterSync) Reconcile(ctx context.Context, request reconcile.Request) (reconcile.Result, error) {
 	logger := controllerutils.BuildControllerLogger(ControllerName, "clusterDeployment", request.NamespacedName)
 	logger.Infof("reconciling ClusterDeployment")
 	recobsrv := hivemetrics.NewReconcileObserver(ControllerName, logger)
@@ -381,11 +375,15 @@ func (r *ReconcileClusterSync) Reconcile(request reconcile.Request) (reconcile.R
 		return reconcile.Result{}, nil
 	}
 
+	if !cd.Spec.Installed {
+		logger.Debug("cluster is not yet installed")
+		return reconcile.Result{}, nil
+	}
+
 	if unreachable, _ := remoteclient.Unreachable(cd); unreachable {
 		logger.Debug("cluster is unreachable")
 		return reconcile.Result{}, nil
 	}
-
 	restConfig, err := r.remoteClusterAPIClientBuilder(cd).RESTConfig()
 	if err != nil {
 		logger.WithError(err).Error("unable to get REST config")
@@ -574,10 +572,12 @@ func (r *ReconcileClusterSync) applySyncSets(
 			ObservedGeneration: syncSet.AsMetaObject().GetGeneration(),
 			Result:             hiveintv1alpha1.SuccessSyncSetResult,
 		}
-		if syncSet.GetSpec().ResourceApplyMode == hivev1.SyncResourceApplyMode {
+		applyMode := syncSet.GetSpec().ResourceApplyMode
+		if applyMode == hivev1.SyncResourceApplyMode {
 			newSyncStatus.ResourcesToDelete = resourcesApplied
 		}
-		if syncSet.GetSpec().ResourceApplyMode == hivev1.UpsertResourceApplyMode && len(oldSyncStatus.ResourcesToDelete) > 0 {
+		// applyMode defaults to UpsertResourceApplyMode
+		if (applyMode == hivev1.UpsertResourceApplyMode || applyMode == "") && len(oldSyncStatus.ResourcesToDelete) > 0 {
 			logger.Infof("resource apply mode is %v but there are resources to delete in clustersync status", hivev1.UpsertResourceApplyMode)
 			oldSyncStatus.ResourcesToDelete = nil
 		}
