@@ -20,12 +20,12 @@ import (
 	"k8s.io/utils/pointer"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
-	machineapi "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
 	installgcp "github.com/openshift/installer/pkg/asset/machines/gcp"
 	installertypes "github.com/openshift/installer/pkg/types"
 	installertypesgcp "github.com/openshift/installer/pkg/types/gcp"
+	machineapi "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	"github.com/openshift/hive/pkg/constants"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
 	"github.com/openshift/hive/pkg/gcpclient"
@@ -35,6 +35,9 @@ const (
 	// Omit m, the installer used this for the master machines. w is also removed as this is implicitly used
 	// by the installer for the original worker pool.
 	validLeaseChars = "abcdefghijklnopqrstuvxyz0123456789"
+
+	defaultGCPDiskType   = "pd-ssd"
+	defaultGCPDiskSizeGB = 128
 )
 
 var (
@@ -50,6 +53,8 @@ type GCPActuator struct {
 	scheme    *runtime.Scheme
 	projectID string
 	imageID   string
+	network   string
+	subnet    string
 	// expectations is a reference to the reconciler's TTLCache of machinepoolnamelease creates each machinepool
 	// expects to see.
 	expectations   controllerutils.ExpectationsInterface
@@ -91,6 +96,12 @@ func NewGCPActuator(
 		return nil, err
 	}
 
+	network, subnet, err := getNetwork(remoteMachineSets, scheme, logger)
+	if err != nil {
+		logger.WithError(err).Error("error getting network information from remote machines")
+		return nil, err
+	}
+
 	actuator := &GCPActuator{
 		gcpClient:      gcpClient,
 		client:         client,
@@ -99,6 +110,8 @@ func NewGCPActuator(
 		expectations:   expectations,
 		projectID:      projectID,
 		imageID:        imageID,
+		network:        network,
+		subnet:         subnet,
 		leasesRequired: requireLeases(clusterVersion, remoteMachineSets, logger),
 	}
 	return actuator, nil
@@ -160,8 +173,10 @@ func (a *GCPActuator) GenerateMachineSets(cd *hivev1.ClusterDeployment, pool *hi
 	ic := &installertypes.InstallConfig{
 		Platform: installertypes.Platform{
 			GCP: &installertypesgcp.Platform{
-				Region:    cd.Spec.Platform.GCP.Region,
-				ProjectID: a.projectID,
+				Region:        cd.Spec.Platform.GCP.Region,
+				ProjectID:     a.projectID,
+				ComputeSubnet: a.subnet,
+				Network:       a.network,
 			},
 		},
 	}
@@ -171,12 +186,36 @@ func (a *GCPActuator) GenerateMachineSets(cd *hivev1.ClusterDeployment, pool *hi
 	computePool.Platform.GCP = &installertypesgcp.MachinePool{
 		Zones:        pool.Spec.Platform.GCP.Zones,
 		InstanceType: pool.Spec.Platform.GCP.InstanceType,
+		// May be overridden below:
 		OSDisk: installertypesgcp.OSDisk{
-			DiskType:   "pd-ssd",
-			DiskSizeGB: 128,
+			DiskType:   defaultGCPDiskType,
+			DiskSizeGB: defaultGCPDiskSizeGB,
 		},
 	}
 
+	poolGCP := pool.Spec.Platform.GCP
+	if pool.Spec.Platform.GCP.OSDisk.DiskType != "" {
+		computePool.Platform.GCP.OSDisk.DiskType = poolGCP.OSDisk.DiskType
+	}
+	if pool.Spec.Platform.GCP.OSDisk.DiskSizeGB != 0 {
+		computePool.Platform.GCP.OSDisk.DiskSizeGB = poolGCP.OSDisk.DiskSizeGB
+	}
+
+	poolEncRef := poolGCP.OSDisk.EncryptionKey
+	if poolEncRef != nil {
+		computePool.Platform.GCP.OSDisk.EncryptionKey = &installertypesgcp.EncryptionKeyReference{
+			KMSKeyServiceAccount: poolEncRef.KMSKeyServiceAccount,
+		}
+		if poolEncRef.KMSKey != nil {
+			computePool.Platform.GCP.OSDisk.EncryptionKey.KMSKey = &installertypesgcp.KMSKeyReference{
+				Name:      poolEncRef.KMSKey.Name,
+				KeyRing:   poolEncRef.KMSKey.KeyRing,
+				ProjectID: poolEncRef.KMSKey.ProjectID,
+				Location:  poolEncRef.KMSKey.Location,
+			}
+		}
+	}
+
 	if len(computePool.Platform.GCP.Zones) == 0 {
 		zones, err := a.getZones(cd.Spec.Platform.GCP.Region)
 		if err != nil {
@@ -424,6 +463,33 @@ func getGCPImageID(masterMachine *machineapi.Machine, scheme *runtime.Scheme, lo
 	return imageID, nil
 }
 
+// getNetwork retrieves the network information (Network name and subnet)
+// from existing machines on the remote cluster.
+func getNetwork(remoteMachineSets []machineapi.MachineSet,
+	scheme *runtime.Scheme, logger log.FieldLogger) (string, string, error) {
+	if len(remoteMachineSets) == 0 {
+		return "", "", nil
+	}
+
+	remoteMachineProviderSpec, err := decodeGCPMachineProviderSpec(
+		remoteMachineSets[0].Spec.Template.Spec.ProviderSpec.Value,
+		scheme,
+	)
+	if err != nil {
+		logger.WithError(err).Warn("cannot decode GCPMachineProviderSpec from remote machinesets")
+		return "", "", errors.Wrap(err, "cannot decode GCPMachineProviderSpec from remote machinesets")
+	}
+
+	if len(remoteMachineProviderSpec.NetworkInterfaces) == 0 {
+		logger.Warn("remote machine do not have any network interfaces")
+		return "", "", errors.Wrap(err, "remote machine do not have any network interfaces")
+	}
+
+	network := remoteMachineProviderSpec.NetworkInterfaces[0].Network
+	subnet := remoteMachineProviderSpec.NetworkInterfaces[0].Subnetwork
+	return network, subnet, nil
+}
+
 func decodeGCPMachineProviderSpec(rawExt *runtime.RawExtension, scheme *runtime.Scheme) (*gcpproviderv1beta1.GCPMachineProviderSpec, error) {
 	codecFactory := serializer.NewCodecFactory(scheme)
 	decoder := codecFactory.UniversalDecoder(gcpproviderv1beta1.SchemeGroupVersion)
