@@ -12,9 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-// Package profiler is a client for the Stackdriver Profiler service.
-//
-// This package is still experimental and subject to change.
+// Package profiler is a client for the Cloud Profiler service.
 //
 // Usage example:
 //
@@ -77,9 +75,14 @@ var (
 	stopCPUProfile   = pprof.StopCPUProfile
 	writeHeapProfile = pprof.WriteHeapProfile
 	sleep            = gax.Sleep
-	dialGRPC         = gtransport.Dial
+	dialGRPC         = gtransport.DialPool
 	onGCE            = gcemd.OnGCE
 	serviceRegexp    = regexp.MustCompile(`^[a-z]([-a-z0-9_.]{0,253}[a-z0-9])?$`)
+
+	// For testing only.
+	// When the profiling loop has exited without error and this channel is
+	// non-nil, "true" will be sent to this channel.
+	profilingDone chan bool
 )
 
 const (
@@ -129,6 +132,9 @@ type Config struct {
 	// than Go 1.8.
 	MutexProfiling bool
 
+	// When true, collecting the CPU profiles is disabled.
+	NoCPUProfiling bool
+
 	// When true, collecting the allocation profiles is disabled.
 	NoAllocProfiling bool
 
@@ -143,6 +149,11 @@ type Config struct {
 	// When true, collecting the goroutine profiles is disabled.
 	NoGoroutineProfiling bool
 
+	// When true, the agent sends all telemetries via OpenCensus exporter, which
+	// can be viewed in Cloud Trace and Cloud Monitoring.
+	// Default is false.
+	EnableOCTelemetry bool
+
 	// ProjectID is the Cloud Console project ID to use instead of the one set by
 	// GOOGLE_CLOUD_PROJECT environment variable or read from the VM metadata
 	// server.
@@ -167,6 +178,11 @@ type Config struct {
 	// and doesn't need to be initialized. It needs to be set in rare cases where
 	// the metadata server is present but is flaky or otherwise misbehave.
 	Zone string
+
+	// numProfiles is the number of profiles which should be collected before
+	// the profile collection loop exits.When numProfiles is 0, profiles will
+	// be collected for the duration of the program. For testing only.
+	numProfiles int
 }
 
 // allowUntilSuccess is an object that will perform action till
@@ -223,15 +239,22 @@ func start(cfg Config, options ...option.ClientOption) error {
 		option.WithScopes(scope),
 		option.WithUserAgent(fmt.Sprintf("gcloud-go-profiler/%s", version.Repo)),
 	}
+	if !config.EnableOCTelemetry {
+		opts = append(opts, option.WithTelemetryDisabled())
+	}
 	opts = append(opts, options...)
 
-	conn, err := dialGRPC(ctx, opts...)
+	connPool, err := dialGRPC(ctx, opts...)
 	if err != nil {
 		debugLog("failed to dial GRPC: %v", err)
 		return err
 	}
 
-	a := initializeAgent(pb.NewProfilerServiceClient(conn))
+	a, err := initializeAgent(pb.NewProfilerServiceClient(connPool))
+	if err != nil {
+		debugLog("failed to start the profiling agent: %v", err)
+		return err
+	}
 	go pollProfilerService(withXGoogHeader(ctx), a)
 	return nil
 }
@@ -304,10 +327,11 @@ func (a *agent) createProfile(ctx context.Context) *pb.Profile {
 	md := grpcmd.New(map[string]string{})
 
 	gax.Invoke(ctx, func(ctx context.Context, settings gax.CallSettings) error {
+		debugLog("creating a new profile via profiler service")
 		var err error
 		p, err = a.client.CreateProfile(ctx, &req, grpc.Trailer(&md))
 		if err != nil {
-			debugLog("failed to create a profile, will retry: %v", err)
+			debugLog("failed to create profile, will retry: %v", err)
 		}
 		return err
 	}, gax.WithRetry(func() gax.Retryer {
@@ -377,15 +401,6 @@ func (a *agent) profileAndUpload(ctx context.Context, p *pb.Profile) {
 		return
 	}
 
-	// Starting Go 1.9 the profiles are symbolized by runtime/pprof.
-	// TODO(jianqiaoli): Remove the symbolization code when we decide to
-	// stop supporting Go 1.8.
-	if !shouldAssumeSymbolized && pt != pb.ProfileType_CONTENTION {
-		if err := parseAndSymbolize(&prof); err != nil {
-			debugLog("failed to symbolize profile: %v", err)
-		}
-	}
-
 	p.ProfileBytes = prof.Bytes()
 	p.Labels = a.profileLabels
 	req := pb.UpdateProfileRequest{Profile: p}
@@ -419,9 +434,6 @@ func deltaMutexProfile(ctx context.Context, duration time.Duration, prof *bytes.
 		return err
 	}
 
-	// The mutex profile is not symbolized by runtime.pprof until
-	// golang.org/issue/21474 is fixed in go1.10.
-	symbolize(p)
 	return p.Write(prof)
 }
 
@@ -450,7 +462,10 @@ func withXGoogHeader(ctx context.Context, keyval ...string) context.Context {
 	return grpcmd.NewOutgoingContext(ctx, md)
 }
 
-func initializeAgent(c pb.ProfilerServiceClient) *agent {
+// initializeAgent initializes the profiling agent. It returns an error if
+// profile collection should not be started because collection is disabled
+// for all profile types.
+func initializeAgent(c pb.ProfilerServiceClient) (*agent, error) {
 	labels := map[string]string{languageLabel: "go"}
 	if config.Zone != "" {
 		labels[zoneNameLabel] = config.Zone
@@ -470,7 +485,10 @@ func initializeAgent(c pb.ProfilerServiceClient) *agent {
 		profileLabels[instanceLabel] = config.Instance
 	}
 
-	profileTypes := []pb.ProfileType{pb.ProfileType_CPU}
+	var profileTypes []pb.ProfileType
+	if !config.NoCPUProfiling {
+		profileTypes = append(profileTypes, pb.ProfileType_CPU)
+	}
 	if !config.NoHeapProfiling {
 		profileTypes = append(profileTypes, pb.ProfileType_HEAP)
 	}
@@ -484,12 +502,16 @@ func initializeAgent(c pb.ProfilerServiceClient) *agent {
 		profileTypes = append(profileTypes, pb.ProfileType_CONTENTION)
 	}
 
+	if len(profileTypes) == 0 {
+		return nil, fmt.Errorf("collection is not enabled for any profile types")
+	}
+
 	return &agent{
 		client:        c,
 		deployment:    d,
 		profileLabels: profileLabels,
 		profileTypes:  profileTypes,
-	}
+	}, nil
 }
 
 func initializeConfig(cfg Config) error {
@@ -566,10 +588,14 @@ func initializeConfig(cfg Config) error {
 // server for instructions, and collects and uploads profiles as
 // requested.
 func pollProfilerService(ctx context.Context, a *agent) {
-	debugLog("Stackdriver Profiler Go Agent version: %s", version.Repo)
+	debugLog("Cloud Profiler Go Agent version: %s", version.Repo)
 	debugLog("profiler has started")
-	for {
+	for i := 0; config.numProfiles == 0 || i < config.numProfiles; i++ {
 		p := a.createProfile(ctx)
 		a.profileAndUpload(ctx, p)
 	}
+
+	if profilingDone != nil {
+		profilingDone <- true
+	}
 }
